import React, { Component } from "react";
import { Switch, Route, withRouter } from "react-router-dom";

import App from "./containers/App";
import Auth from "./containers/Auth";

import Header from "./components/header";

import PrivateRoute from "./privateRouter";
import { Provider } from "./index";

class Router extends Component {
	state = { token: null, count: 0 };

	componentDidMount() {
		const token = localStorage.getItem("token");

		if (token) {
			return this.setState({ token });
		}
	}

	changeCount = () => this.setState(prevState => ({ count: prevState.count + 1 }));

	setToken = token => {
		localStorage.setItem("token", token);
		this.setState({ token });
	};

	render() {
		const { token, count } = this.state;
		// console.log("token", token);
		return (
			<Provider value={{ token, setToken: this.setToken, count, changeCount: this.changeCount }}>
				<div className="container">
					<Header />
					<Switch>
						<PrivateRoute token={token} exact path="/" component={App} />
						<Route exact path="/auth" component={Auth} />
					</Switch>
				</div>
			</Provider>
		);
	}
}

export default withRouter(Router);
